# visualimiss
"**visuali**ze **miss**ing data". A simple [missingno](https://github.com/ResidentMario/missingno)
clone. Some features were removed from the original and some were added.

# Installation
```python
pip install visualimiss
```

# Features
Some features differ from the original one:
- Have `matrix()`, `bar()` modified function from the original one
- Simpler and faster
- Maybe more readable?